@@ -23,7 +23,7 @@ Version 0.03
 
 =cut
 
-our $VERSION = '0.032';
+our $VERSION = '0.033';
 
 
 =head1 SYNOPSIS
@@ -353,7 +353,7 @@ sub _non_payload_files {
   my @payload = ();
   File::Find::find( sub {
     if(-f $File::Find::name) {
-      my ($relpath) = ($File::Find::name=~m!$self->{"bag_path"}(/.*$)!);
+      my ($relpath) = ($File::Find::name=~m!$self->{"bag_path"}/(.*$)!);
       push(@payload, $relpath);
     }
     elsif(-d _ && $_ eq "data") {
